#!/usr/bin/env bash

ARGV=("$@")


###
# http://stackoverflow.com/a/23342259
###
exe() { echo "\$ $@" ; "$@" ; }

show_usage () {
  echo ""
  echo "Set up the building of libssts and clean up too."
  echo "  ./build.sh clean      -  Clean up the project and build files."
  echo ""
  echo "  ./build.sh build      -  Create the build directory, run CMake (if"
  echo "                           needed) and build libssts."
  echo ""
  echo "  ./build.sh help       -  Show this helpful help text."
  echo ""
  echo "  ./build.sh clean-tree -  clean the bzr three. reverting all and any"
  echo "                           changes made to the file tree since the last"
  echo "                           commit."
  echo ""
  echo "  ./build.sh commit     -  commit changes."
  echo ""
  echo "  ./build.sh branch <name> - create a branch. This will cd up one level"
  echo "                             and then do a branch. The name of the"
  echo "                             branch will be \"simpletypesystem_<name>\"."
}

do_build () {
  if ( ! -d "./build" )
  then
    exe mkdir ./build
  fi
  
  cd ./build
  
  if [ ! -f "Makefile" ]
  then
    exe cmake ..
  fi
  
  make
}

do_clean () {
  if [ -d "./build" ]
  then
    exe rm -R ./build
  fi
}

do_clean_tree () {
  exe bzr revert
  exe bzr clean-tree 
}

do_commit () {
  exe bzr commit
}

do_branch () {
  echo ${ARGV[1]}
  if [[ -z ${ARGV[1]} ]]
  then
    echo "Missing branch name."
    show_usage
    exit
  else
    #build up the branch name.
    NEW_BRANCH_NAME="simpletypesystem_"${ARGV[1]}
    CURRENT_WD=$(pwd)
    exe cd ..
    PARENT_WD=$(pwd)
    exe bzr branch $CURRENT_WD $PARENT_WD/$NEW_BRANCH_NAME
    if [[ $? ]]
    then
      echo ""
      echo "Something went wrong when trying to branch..."
    else
      echo ""
      echo "The directory $PARENT_WD/$NEW_BRANCH_NAME is ready. To go to that"
      echo "branch cd to it."
      echo ""
      echo "Remember to commit often and run"
      echo "$ bzr push --remember lp:~<lp-username>/simpletypesystem/${ARGV[1]}"
      echo "before you start hacking."
    fi
  fi
}

case ${ARGV[0]} in
     "help"|"-h") show_usage ;;
     "clean") do_clean ;;
     "build"|"") do_build ;;
     "clean-tree") do_clean_tree ;;
     "branch") do_branch ;;
     *) show_usage ;;
esac



